==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/firewall/translations/firewall_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Firewall</source>
        <translation>Ohnivá zeď</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Notify</source>
        <translation>Oznámit</translation>
    </message>
    <message>
        <source>Notification syntax</source>
        <translation>Skladba oznámení</translation>
    </message>
    <message>
        <source>%u - uin, %m - message</source>
        <translation>%u - uin, %m - zpráva</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Zápis</translation>
    </message>
    <message>
        <source>Write to history</source>
        <translation>Zapsat do historie</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Zapsat zápis do souboru</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Search for unknown person in directory and show window with his personal data.</source>
        <translation>Hledat v adresáři neznámé osoby a ukázat okno s jejich daty.</translation>
    </message>
    <message>
        <source>Unknown chats protection</source>
        <translation>Ochrana před hovory s neznámými</translation>
    </message>
    <message>
        <source>Ignore conferences with all persons unknown</source>
        <translation>Nevšímat si porad, když jsou všichni účastníci neznámí</translation>
    </message>
    <message>
        <source>Protect against chats with unknown persons</source>
        <translation>Ochrana před hovory s neznámými účastníky</translation>
    </message>
    <message>
        <source>When invisible silently drop chats with unknown persons</source>
        <translation>Když jste neviditelný, zahodit hovory s neznámými - bez nějakého dalšího hlášení</translation>
    </message>
    <message>
        <source>Automatic question</source>
        <translation>Automaticky položená otázka</translation>
    </message>
    <message>
        <source>After right answer</source>
        <translation>Po správné odpovědi</translation>
    </message>
    <message>
        <source>Send confirmation</source>
        <translation>Poslat potvrzení</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation>Potvrzení</translation>
    </message>
    <message>
        <source>DoS attack</source>
        <translation>Útok typu DoS</translation>
    </message>
    <message>
        <source>Protect against flooding DoS attack</source>
        <translation>Chránit před přetečením způsobeným zprávami útoku typu DoS</translation>
    </message>
    <message>
        <source>Attack caused by many messages, sent in short time.</source>
        <translation>Ǔtok zapříčiněný posíláním nespočetných zpráv po krátkou dobu.</translation>
    </message>
    <message>
        <source>Min delay between two messages</source>
        <translation>Nejmenší odstup mezi dvěma zprávami</translation>
    </message>
    <message>
        <source>Emoticons DoS attack</source>
        <translation>Útok typu DoS pomocí ksichtíků</translation>
    </message>
    <message>
        <source>Protect against emoticons DoS attack</source>
        <translation>Chránit před útokem pomocí hordy ksichtů</translation>
    </message>
    <message>
        <source>Attack caused by many emoticons, sent in short time.</source>
        <translation>Ǔtok zapříčiněný posíláním nespočetných ksichtů po krátkou dobu.</translation>
    </message>
    <message>
        <source>Max number of emoticons in one message</source>
        <translation>Největší počet symbolů v jedné zprávě</translation>
    </message>
    <message>
        <source>Allow if known contact</source>
        <translation>Povolit, když je odesílatel zařazen v seznamu spojení</translation>
    </message>
    <message>
        <source>People from your list can send you unlimited number of emoticons</source>
        <translation>Lidé ve vašem seznamu vám mohou posílat neomezený počet svých obličejíků</translation>
    </message>
    <message>
        <source>Safe sending</source>
        <translation>Bezpečné posílání</translation>
    </message>
    <message>
        <source>Enable safe sending</source>
        <translation>Povolit bezpečné posílání</translation>
    </message>
    <message>
        <source>You must confirm each message sent to these people</source>
        <translation>Musíte potvrdit každou zprávu, kterou chcete těmto lidem poslat</translation>
    </message>
    <message numerus="yes">
        <source>%n millisecond(s)</source>
        <translation>
            <numerusform>1 milisekunda</numerusform>
            <numerusform>%n milisekundy</numerusform>
            <numerusform>%n milisekund</numerusform>
        </translation>
    </message>
    <message>
        <source>Module will ask the question typed below, if someone wants talk to you and you do not have him on your list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message was firewalled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Firewall</name>
    <message>
        <source>I want something</source>
        <translation>Něco chci</translation>
    </message>
    <message>
        <source>flooding DoS attack with emoticons!</source>
        <translation>Ǔtok ksichty hrozící způsobit přetečení, typ DoS!</translation>
    </message>
    <message>
        <source>flooding DoS attack!</source>
        <translation>Útok typu DoS hrozící způsobit přetečení!</translation>
    </message>
    <message>
        <source>Chat with anonim silently dropped.
</source>
        <translation>Hovor s neznámým tiše zahozen.
</translation>
    </message>
    <message>
        <source>OK, now say hello, and introduce yourself ;-)</source>
        <translation>OK. A teď si představ sám sebe ;-)</translation>
    </message>
    <message>
        <source>User wrote right answer!
</source>
        <translation>Uživatel napsal správnou odpověď!</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
        <translation>Tato zpráva byla vytvořena AUTOMATICKY!

Jsem velmi zaměstnán a nechci být rušen zatažením do hloupých řečí. Najdi si někoho jiného. Když po mě ale něco budeš chtít, jednoduše napiš &quot;Něco chci&quot; (a je jedno, jestli velkými nebo malými písmeny)</translation>
    </message>
    <message>
        <source>Are you sure you want to send this message?</source>
        <translation>Opravdu chcete odeslat tuto zprávu?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ano</translation>
    </message>
    <message>
        <source>Yes and allow until chat closed</source>
        <translation>Ano a dovoluji to až do skončení hovoru</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Ne</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>%u píše</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
        <translation>Tato zpráva byla vytvořena AUTOMATICKY!

Jsem velmi zaměstnán a nemám čas na kecání s lidmi, co sami sebe skrývají. Jestli se mnou chceš mluvit, nejprve si změň stav na připojený nebo zaneprázdněný.</translation>
    </message>
    <message>
        <source>Chat with invisible anonim ignored.
</source>
        <translation>Hovor s někým neviditelným a neznámým přehlížen.
</translation>
    </message>
    <message>
        <source>      DATA AND TIME      ::   ID      :: MESSAGE
</source>
        <translation>      DATUM A ČAS      ::   ID      :: ZPRÁVA</translation>
    </message>
</context>
<context>
    <name>FirewallConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Secured&apos;</source>
        <translation>Přesunout do &apos;Bezpečných&apos;</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Move to &apos;All&apos;</source>
        <translation>Přesunout do &apos;Vše&apos;</translation>
    </message>
    <message>
        <source>Secured</source>
        <translation>Bezpečné</translation>
    </message>
    <message>
        <source>This message will be send to unknown person.</source>
        <translation>Tato zpráva bude poslána neznámé osobě.</translation>
    </message>
    <message>
        <source>Right answer for question above - you can use regexp.</source>
        <translation>Správná odpověď na otázku položenou výše - můžete použít regulární výrazy.</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpověď:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Zpráva:</translation>
    </message>
</context>
<context>
    <name>FirewallNotification</name>
    <message>
        <source>Message was blocked</source>
        <translation>Zpráva byla zablokována</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>%u píše</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/firewall/translations/firewall_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Firewall</source>
        <translation>Ohnivá zeď</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Notify</source>
        <translation>Oznámit</translation>
    </message>
    <message>
        <source>Notification syntax</source>
        <translation>Skladba oznámení</translation>
    </message>
    <message>
        <source>%u - uin, %m - message</source>
        <translation>%u - uin, %m - zpráva</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Zápis</translation>
    </message>
    <message>
        <source>Write to history</source>
        <translation>Zapsat do historie</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Zapsat zápis do souboru</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Search for unknown person in directory and show window with his personal data.</source>
        <translation>Hledat v adresáři neznámé osoby a ukázat okno s jejich daty.</translation>
    </message>
    <message>
        <source>Unknown chats protection</source>
        <translation>Ochrana před hovory s neznámými</translation>
    </message>
    <message>
        <source>Ignore conferences with all persons unknown</source>
        <translation>Nevšímat si porad, když jsou všichni účastníci neznámí</translation>
    </message>
    <message>
        <source>Protect against chats with unknown persons</source>
        <translation>Ochrana před hovory s neznámými účastníky</translation>
    </message>
    <message>
        <source>When invisible silently drop chats with unknown persons</source>
        <translation>Když jste neviditelný, zahodit hovory s neznámými - bez nějakého dalšího hlášení</translation>
    </message>
    <message>
        <source>Automatic question</source>
        <translation>Automaticky položená otázka</translation>
    </message>
    <message>
        <source>After right answer</source>
        <translation>Po správné odpovědi</translation>
    </message>
    <message>
        <source>Send confirmation</source>
        <translation>Poslat potvrzení</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation>Potvrzení</translation>
    </message>
    <message>
        <source>DoS attack</source>
        <translation>Útok typu DoS</translation>
    </message>
    <message>
        <source>Protect against flooding DoS attack</source>
        <translation>Chránit před přetečením způsobeným zprávami útoku typu DoS</translation>
    </message>
    <message>
        <source>Attack caused by many messages, sent in short time.</source>
        <translation>Útok zapříčiněný posíláním nespočetných zpráv po krátkou dobu.</translation>
    </message>
    <message>
        <source>Min delay between two messages</source>
        <translation>Nejmenší odstup mezi dvěma zprávami</translation>
    </message>
    <message>
        <source>Emoticons DoS attack</source>
        <translation>Útok typu DoS pomocí ksichtíků</translation>
    </message>
    <message>
        <source>Protect against emoticons DoS attack</source>
        <translation>Chránit před útokem pomocí hordy ksichtů</translation>
    </message>
    <message>
        <source>Attack caused by many emoticons, sent in short time.</source>
        <translation>Útok zapříčiněný posíláním nespočetných ksichtů po krátkou dobu.</translation>
    </message>
    <message>
        <source>Max number of emoticons in one message</source>
        <translation>Největší počet symbolů v jedné zprávě</translation>
    </message>
    <message>
        <source>Allow if known contact</source>
        <translation>Povolit, když je odesílatel zařazen v seznamu spojení</translation>
    </message>
    <message>
        <source>People from your list can send you unlimited number of emoticons</source>
        <translation>Lidé ve vašem seznamu vám mohou posílat neomezený počet svých obličejíků</translation>
    </message>
    <message>
        <source>Safe sending</source>
        <translation>Bezpečné posílání</translation>
    </message>
    <message>
        <source>Enable safe sending</source>
        <translation>Povolit bezpečné posílání</translation>
    </message>
    <message>
        <source>You must confirm each message sent to these people</source>
        <translation>Musíte potvrdit každou zprávu, kterou chcete těmto lidem poslat</translation>
    </message>
    <message numerus="yes">
        <source>%n millisecond(s)</source>
        <translation><numerusform>1 milisekunda</numerusform><numerusform>%n milisekundy</numerusform><numerusform>%n milisekund</numerusform></translation>
    </message>
    <message>
        <source>Message was firewalled</source>
        <translation>Zpráva byla zadržena ohnivou zdí</translation>
    </message>
    <message>
        <source>Module will ask the question typed below, if someone wants talk to you and you do not have him on your list.</source>
        <translation>Modul položí otázku napsanou níže, když s vámi bude chtít někdo mluvit, ale vy jej nemáte zapsaného ve svém seznamu.</translation>
    </message>
</context>
<context>
    <name>Firewall</name>
    <message>
        <source>I want something</source>
        <translation>Něco chci</translation>
    </message>
    <message>
        <source>flooding DoS attack with emoticons!</source>
        <translation>Útok ksichty hrozící způsobit přetečení, typ DoS!</translation>
    </message>
    <message>
        <source>flooding DoS attack!</source>
        <translation>Útok typu DoS hrozící způsobit přetečení!</translation>
    </message>
    <message>
        <source>Chat with anonim silently dropped.
</source>
        <translation>Hovor s neznámým tiše zahozen.
</translation>
    </message>
    <message>
        <source>OK, now say hello, and introduce yourself ;-)</source>
        <translation>OK. A teď si představ sám sebe ;-)</translation>
    </message>
    <message>
        <source>User wrote right answer!
</source>
        <translation>Uživatel napsal správnou odpověď!</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
        <translation>Tato zpráva byla vytvořena AUTOMATICKY!

Jsem velmi zaměstnán a nechci být rušen zatažením do hloupých řečí. Najdi si někoho jiného. Když po mě ale něco budeš chtít, jednoduše napiš &quot;Něco chci&quot; (a je jedno, jestli velkými nebo malými písmeny)</translation>
    </message>
    <message>
        <source>Are you sure you want to send this message?</source>
        <translation>Opravdu chcete odeslat tuto zprávu?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ano</translation>
    </message>
    <message>
        <source>Yes and allow until chat closed</source>
        <translation>Ano a dovoluji to až do skončení hovoru</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Ne</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>%u píše</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
        <translation>Tato zpráva byla vytvořena AUTOMATICKY!

Jsem velmi zaměstnán a nemám čas na kecání s lidmi, co sami sebe skrývají. Jestli se mnou chceš mluvit, nejprve si změň stav na připojený nebo zaneprázdněný.</translation>
    </message>
    <message>
        <source>Chat with invisible anonim ignored.
</source>
        <translation>Hovor s někým neviditelným a neznámým přehlížen.
</translation>
    </message>
    <message>
        <source>      DATA AND TIME      ::   ID      :: MESSAGE
</source>
        <translation>      DATUM A ČAS      ::   ID      :: ZPRÁVA</translation>
    </message>
</context>
<context>
    <name>FirewallConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Secured&apos;</source>
        <translation>Přesunout do bezpečných</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Move to &apos;All&apos;</source>
        <translation>Přesunout do Vše</translation>
    </message>
    <message>
        <source>Secured</source>
        <translation>Bezpečné</translation>
    </message>
    <message>
        <source>This message will be send to unknown person.</source>
        <translation>Tato zpráva bude poslána neznámé osobě.</translation>
    </message>
    <message>
        <source>Right answer for question above - you can use regexp.</source>
        <translation>Správná odpověď na otázku položenou výše - můžete použít regulární výrazy.</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpověď:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Zpráva:</translation>
    </message>
</context>
<context>
    <name>FirewallNotification</name>
    <message>
        <source>Message was blocked</source>
        <translation>Zpráva byla zablokována</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>%u píše</translation>
    </message>
</context>
</TS>
